@@ -40,7 +40,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--prefix=/opt/anaconda1anaconda2anaconda3' "
                 "'--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' "
                 "'--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib "
-                "-ltcl8.5 -ltk8.5' '--enable-loadable-sqlite-extensions' "
+                "-ltcl8.6 -ltk8.6' '--enable-loadable-sqlite-extensions' "
                 "'LDFLAGS=-L/opt/anaconda1anaconda2anaconda3/lib "
                 "-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed' "
                 "'CPPFLAGS=-I/opt/anaconda1anaconda2anaconda3/include' "
@@ -48,8 +48,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
  'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3/coverage.info',
- 'COVERAGE_REPORT': '/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3/lcov-report',
+ 'COVERAGE_INFO': '/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4/coverage.info',
+ 'COVERAGE_REPORT': '/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include '
@@ -131,10 +131,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_COPYSIGN': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -622,7 +630,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4',
  'SCRIPTDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -649,7 +657,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-36m-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
+ 'SRCDIRS': 'Parser Objects Python Modules Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -661,13 +669,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '-I/opt/anaconda1anaconda2anaconda3/include',
  'TCLTK_LIBS': '-L/opt/anaconda1anaconda2anaconda3/lib '
-               '-ltcl8.5 -ltk8.5',
+               '-ltcl8.6 -ltk8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -676,6 +684,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
+ 'UPDATE_FILE': 'python3.6 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
  'VERSION': '3.6',
@@ -691,8 +700,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3',
- 'abs_srcdir': '/feedstock_root/build_artefacts/python_1507212349826/work/Python-3.6.3',
+ 'abs_builddir': '/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4',
+ 'abs_srcdir': '/feedstock_root/build_artefacts/python_1514046575107/work/Python-3.6.4',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
